package com.bonus.canteen.core.menu.mapper;

import java.time.LocalDate;
import java.util.List;
import java.util.Set;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.bonus.canteen.core.alloc.domain.AppletReserveCanteenVO;
import com.bonus.canteen.core.alloc.domain.MenuStallSaleModel;
import com.bonus.canteen.core.menu.domain.MenuAppRecipe;
import com.bonus.canteen.core.menu.domain.MenuRecipe;
import com.bonus.canteen.core.menu.vo.AppletReserveRecipeVO;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

/**
 * 移动端菜谱绑定关系Mapper接口
 * 
 * @author xsheng
 * @date 2025-04-03
 */
public interface MenuAppRecipeMapper {
    /**
     * 查询移动端菜谱绑定关系
     * 
     * @param id 移动端菜谱绑定关系主键
     * @return 移动端菜谱绑定关系
     */
    public MenuAppRecipe selectMenuAppRecipeById(Long id);

    /**
     * 查询移动端菜谱绑定关系列表
     * 
     * @param menuAppRecipe 移动端菜谱绑定关系
     * @return 移动端菜谱绑定关系集合
     */
    public List<MenuAppRecipe> selectMenuAppRecipeList(MenuAppRecipe menuAppRecipe);

    /**
     * 新增移动端菜谱绑定关系
     * 
     * @param menuAppRecipe 移动端菜谱绑定关系
     * @return 结果
     */
    public int insertMenuAppRecipe(MenuAppRecipe menuAppRecipe);

    /**
     * 修改移动端菜谱绑定关系
     * 
     * @param menuAppRecipe 移动端菜谱绑定关系
     * @return 结果
     */
    public int updateMenuAppRecipe(MenuAppRecipe menuAppRecipe);

    /**
     * 删除移动端菜谱绑定关系
     * 
     * @param id 移动端菜谱绑定关系主键
     * @return 结果
     */
    public int deleteMenuAppRecipeById(Long id);

    List<AppletReserveCanteenVO> selectReserveMealCanteenList();

    List<MenuStallSaleModel> selectMonthSalesStall(@Param("stallIdList") List<Long> stallIdList);

    /**
     * 批量删除移动端菜谱绑定关系
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMenuAppRecipeByIds(Long[] ids);

    List<AppletReserveRecipeVO> selectReserveRecipe(@Param("applyDate") LocalDate applyDate, @Param("recipeId") Long recipeId);

    @Select({"select stall_id from menu_recipe ${ew.customSqlSegment}"})
    Long selectStallIdByWrappers(@Param("ew") Wrapper<MenuRecipe> wrapper);
}
