package com.bonus.canteen.core.menu.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.bonus.canteen.core.alloc.domain.AllocMobileCanteenQueryDTO;
import com.bonus.canteen.core.menu.domain.MenuAppRecipe;
import com.bonus.canteen.core.menu.dto.AppletReserveRecipeDTO;
import com.bonus.canteen.core.menu.service.IMenuAppRecipeService;
import com.bonus.common.log.enums.OperaType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 移动端菜谱绑定关系Controller
 * 
 * @author xsheng
 * @date 2025-04-03
 */
@Api(tags = "移动端菜谱绑定关系接口")
@RestController
@RequestMapping("/menu_app_recipe")
@Slf4j
public class MenuAppRecipeController extends BaseController {
    @Autowired
    private IMenuAppRecipeService menuAppRecipeService;

    /**
     * 查询移动端菜谱绑定关系列表
     */
    @ApiOperation(value = "查询移动端菜谱绑定关系列表")
    //@RequiresPermissions("menu:recipe:list")
    @GetMapping("/list")
    public TableDataInfo list(MenuAppRecipe menuAppRecipe) {
        startPage();
        List<MenuAppRecipe> list = menuAppRecipeService.selectMenuAppRecipeList(menuAppRecipe);
        return getDataTable(list);
    }

    /**
     * 导出移动端菜谱绑定关系列表
     */
    @ApiOperation(value = "导出移动端菜谱绑定关系列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:recipe:export")
    @SysLog(title = "移动端菜谱绑定关系", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出移动端菜谱绑定关系")
    @PostMapping("/export")
    public void export(HttpServletResponse response, MenuAppRecipe menuAppRecipe) {
        List<MenuAppRecipe> list = menuAppRecipeService.selectMenuAppRecipeList(menuAppRecipe);
        ExcelUtil<MenuAppRecipe> util = new ExcelUtil<MenuAppRecipe>(MenuAppRecipe.class);
        util.exportExcel(response, list, "移动端菜谱绑定关系数据");
    }

    /**
     * 获取移动端菜谱绑定关系详细信息
     */
    @ApiOperation(value = "获取移动端菜谱绑定关系详细信息")
    //@RequiresPermissions("menu:recipe:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(menuAppRecipeService.selectMenuAppRecipeById(id));
    }

    /**
     * 新增移动端菜谱绑定关系
     */
    @ApiOperation(value = "新增移动端菜谱绑定关系")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:recipe:add")
    @SysLog(title = "移动端菜谱绑定关系", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增移动端菜谱绑定关系")
    @PostMapping
    public AjaxResult add(@RequestBody MenuAppRecipe menuAppRecipe) {
        try {
            return toAjax(menuAppRecipeService.insertMenuAppRecipe(menuAppRecipe));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改移动端菜谱绑定关系
     */
    @ApiOperation(value = "修改移动端菜谱绑定关系")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:recipe:edit")
    @SysLog(title = "移动端菜谱绑定关系", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改移动端菜谱绑定关系")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody MenuAppRecipe menuAppRecipe) {
        try {
            return toAjax(menuAppRecipeService.updateMenuAppRecipe(menuAppRecipe));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除移动端菜谱绑定关系
     */
    @ApiOperation(value = "删除移动端菜谱绑定关系")
    //@PreventRepeatSubmit
    //@RequiresPermissions("menu:recipe:remove")
    @SysLog(title = "移动端菜谱绑定关系", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除移动端菜谱绑定关系")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(menuAppRecipeService.deleteMenuAppRecipeByIds(ids));
    }

    @ApiOperation("获取预定餐食堂列表")
    @GetMapping({"/reserve/canteen/shopstall/list"})
    public TableDataInfo getReserveMealCanteenList() {
        try {
            startPage();
            return getDataTable(this.menuAppRecipeService.getReserveMealCanteenList());
        } catch (Exception e) {
            log.error(e.toString(), e);
            return getDataTable(null);
        }
    }

    @ApiOperation("移动端-查询预订日期列表")
    @PostMapping({"/reserve-date/list"})
    public AjaxResult listReserveDate(@RequestBody AllocMobileCanteenQueryDTO bean) {
        return AjaxResult.success(this.menuAppRecipeService.listReserveDate(bean));
    }

    @ApiOperation("获取预定餐菜谱详情")
    @PostMapping({"/reserve/recipe/detail"})
    public TableDataInfo getReserveRecipeDetailList(@RequestBody AppletReserveRecipeDTO content) {
        try {
            startPage();
            return getDataTable(this.menuAppRecipeService.getReserveRecipeDetailList(content));
        } catch (Exception e) {
            log.error(e.toString(), e);
            return getDataTable(null);
        }
    }
}
